#! /bin/sh

# Test pmldigital applied to images from a film scanner

tmpxml='tmp.xml'
../pmldigital -s -f -d 200*.tif.bz2 > $tmpxml
if [ "$1" = 's' ]; then
  ../pmlvalid $tmpxml 1>/dev/null
else
  ../pmlvalid $tmpxml 1>&2
fi
es=$?
rm $tmpxml
exit $es
